@@ -1,10 +1,15 @@
+# Copyright (c) 2014, cPanel, Inc.
+# All rights reserved.
+# http://cpanel.net/
+#
+# This is free software; you can redistribute it and/or modify it under the same
+# terms as Perl itself.  See the LICENSE file for further details.
+
 package Mail::Alias::Reader::Token;
 
 use strict;
 use warnings;
 
-use Carp;
-
 =head1 NAME
 
 Mail::Alias::Reader::Token
@@ -23,7 +28,7 @@ my @TOKEN_TYPES = (
     [ 'T_COMMENT'    => qr/#\s*(.*)$/ ],
     [ 'T_STRING'     => qr/("(?:\\.|[^"\\]+)*")/ ],
     [ 'T_COMMA'      => qr/,/ ],
-    [ 'T_DIRECTIVE'  => qr/:([^\:\s]+):([^\:\s,]+)/ ],
+    [ 'T_DIRECTIVE'  => qr/:([^\:\s]+):([^\:\s,]*)/ ],
     [ 'T_COMMAND'    => qr/\|(\S+)/ ],
     [ 'T_ADDRESS'    => qr/([a-z0-9_\-@\.*]+)/i ],
     [ 'T_COLON'      => qr/\:/ ],
@@ -179,7 +184,7 @@ sub to_string {
     my $value = $self->{'value'};
 
     if ($value) {
-        foreach my $search (keys %SUBSTITUTIONS) {
+        foreach my $search ( keys %SUBSTITUTIONS ) {
             $value =~ s/$search/$SUBSTITUTIONS{$search}/g;
         }
     }
@@ -293,8 +298,8 @@ sub tokenize {
     );
 
     my @STRING_ESCAPE_SEQUENCES = (
-        [ qr/\\(0\d*)/       => sub { pack 'W', oct($1) } ],
-        [ qr/\\(x[0-9a-f]+)/ => sub { pack 'W', hex("0$1") } ],
+        [ qr/\\(0\d*)/       => sub { pack 'C', oct($1) } ],
+        [ qr/\\(x[0-9a-f]+)/ => sub { pack 'C', hex("0$1") } ],
         [ qr/\\([rnt])/      => sub { $WHITESPACE{$1} } ],
         [ qr/\\([^rnt])/     => sub { $1 } ]
     );
@@ -328,7 +333,7 @@ sub tokenize {
             # contents, copying the data directly into the existing token (so as to
             # not lose the previous reference).
             #
-            %{$token} = %{$class->tokenize_for_types( $token->{'value'}, @TOKEN_STRING_TYPES )->[0]};
+            %{$token} = %{ $class->tokenize_for_types( $token->{'value'}, @TOKEN_STRING_TYPES )->[0] };
         }
     }
 
@@ -345,8 +350,13 @@ __END__
 
 =head1 AUTHOR
 
-Erin Schoenhals E<lt>erin@cpanel.netE<gt>
+Written and maintained by Xan Tronix <xan@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright(c) 2011 cPanel, Inc.  All rights reserved.
+Copyright (c) 2014, cPanel, Inc.
+All rights reserved.
+http://cpanel.net/
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as Perl itself.  See the LICENSE file for further details.
